# EllucianEthosPythonClient
Python Client Library for interfacing with Ellucian Ethos. It is built by some members of the Ethos customer the 
community. 

Currently in development -and not fully tested for production use.

## Aims

This library aims to provide:

 - Wrapper class to handle Ethos authorizations
 - Wrapper classes that call Ellucian API's to fetch resources
 - Common updates on resources
 - Change notification poller
 - Provide mock running mode to allow for testing without calling Ethos
 
## Usage examples

 - For a quick start usage example using the python REPL console follow the [Quickstart](./docs/QUICKSTART.md) guide.
 - For examples of using the poller functionality see [Poller Guide](./docs/POLLERGUIDE.md)
 - For sample scripts see [Sample scripts directory](./samples)

## Background

I started putting this python library after an Ethos user group meeting. There are a number of other Ellucian customers
all writing clients and I wanted to take the opportunity of digging out exmaples I had written for myself and my team
and sharing them with the community. I hope that publishing this library is useful to other Ethos users and hope to 
collaborate on improving it further. Please feel free to submit feedback, issues and pull requests.
  
 

